==> ZenTaoALM.12.4.2.int.zip: zentaoalm/module/upgrade/lang/version.php <==
<?php
$lang->upgrade->fromVersions['0_3beta']    = '0.3 BETA';
$lang->upgrade->fromVersions['0_4beta']    = '0.4 BETA';
$lang->upgrade->fromVersions['0_5beta']    = '0.5 BETA';
$lang->upgrade->fromVersions['0_6beta']    = '0.6 BETA';
$lang->upgrade->fromVersions['1_0beta']    = '1.0 BETA';
$lang->upgrade->fromVersions['1_0rc1']     = '1.0 RC1';
$lang->upgrade->fromVersions['1_0rc2']     = '1.0 RC2';
$lang->upgrade->fromVersions['1_0']        = '1.0 STABLE';
$lang->upgrade->fromVersions['1_0_1']      = '1.0.1';
$lang->upgrade->fromVersions['1_1']        = '1.1';
$lang->upgrade->fromVersions['1_2']        = '1.2';
$lang->upgrade->fromVersions['1_3']        = '1.3';
$lang->upgrade->fromVersions['1_4']        = '1.4';
$lang->upgrade->fromVersions['1_5']        = '1.5';
$lang->upgrade->fromVersions['2_0']        = '2.0';
$lang->upgrade->fromVersions['2_1']        = '2.1';
$lang->upgrade->fromVersions['2_2']        = '2.2';
$lang->upgrade->fromVersions['2_3']        = '2.3';
$lang->upgrade->fromVersions['2_4']        = '2.4';
$lang->upgrade->fromVersions['3_0_beta1']  = '3.0 BETA1';
$lang->upgrade->fromVersions['3_0_beta2']  = '3.0 BETA2';
$lang->upgrade->fromVersions['3_0']        = '3.0 STABLE';
$lang->upgrade->fromVersions['3_1']        = '3.1';
$lang->upgrade->fromVersions['3_2']        = '3.2';
$lang->upgrade->fromVersions['3_2_1']      = '3.2.1';
$lang->upgrade->fromVersions['3_3']        = '3.3';
$lang->upgrade->fromVersions['4_0_beta1']  = '4.0 BETA1';
$lang->upgrade->fromVersions['4_0_beta2']  = '4.0 BETA2';
$lang->upgrade->fromVersions['4_0']        = '4.0';
$lang->upgrade->fromVersions['4_0_1']      = '4.0.1';
$lang->upgrade->fromVersions['4_1']        = '4.1';
$lang->upgrade->fromVersions['4_2_beta']   = '4.2.beta';
$lang->upgrade->fromVersions['4_3_beta']   = '4.3.beta';
$lang->upgrade->fromVersions['5_0_beta1']  = '5.0.beta1';
$lang->upgrade->fromVersions['5_0_beta2']  = '5.0.beta2';
$lang->upgrade->fromVersions['5_0']        = '5.0';
$lang->upgrade->fromVersions['5_1']        = '5.1';
$lang->upgrade->fromVersions['5_2']        = '5.2';
$lang->upgrade->fromVersions['5_2_1']      = '5.2.1';
$lang->upgrade->fromVersions['5_3']        = '5.3';
$lang->upgrade->fromVersions['6_0_beta1']  = '6.0.beta1';
$lang->upgrade->fromVersions['6_0']        = '6.0';
$lang->upgrade->fromVersions['6_1']        = '6.1';
$lang->upgrade->fromVersions['6_2']        = '6.2';
$lang->upgrade->fromVersions['6_3']        = '6.3';
$lang->upgrade->fromVersions['6_4']        = '6.4';
$lang->upgrade->fromVersions['7_0']        = '7.0';
$lang->upgrade->fromVersions['7_1']        = '7.1';
$lang->upgrade->fromVersions['7_2']        = '7.2';
$lang->upgrade->fromVersions['7_2_4']      = '7.2.4';
$lang->upgrade->fromVersions['7_2_5']      = '7.2.5';
$lang->upgrade->fromVersions['7_3']        = '7.3';
$lang->upgrade->fromVersions['7_4_beta']   = '7.4.beta';
$lang->upgrade->fromVersions['8_0']        = '8.0';
$lang->upgrade->fromVersions['8_0_1']      = '8.0.1';
$lang->upgrade->fromVersions['8_1']        = '8.1';
$lang->upgrade->fromVersions['8_1_3']      = '8.1.3';
$lang->upgrade->fromVersions['8_2_beta']   = '8.2.beta';
$lang->upgrade->fromVersions['8_2']        = '8.2';
$lang->upgrade->fromVersions['8_2_1']      = '8.2.1';
$lang->upgrade->fromVersions['8_2_2']      = '8.2.2';
$lang->upgrade->fromVersions['8_2_3']      = '8.2.3';
$lang->upgrade->fromVersions['8_2_4']      = '8.2.4';
$lang->upgrade->fromVersions['8_2_5']      = '8.2.5';
$lang->upgrade->fromVersions['8_2_6']      = '8.2.6';
$lang->upgrade->fromVersions['8_3']        = '8.3';
$lang->upgrade->fromVersions['8_3_1']      = '8.3.1';
$lang->upgrade->fromVersions['8_4']        = '8.4';
$lang->upgrade->fromVersions['8_4_1']      = '8.4.1';
$lang->upgrade->fromVersions['9_0_beta']   = '9.0.beta';
$lang->upgrade->fromVersions['9_0']        = '9.0';
$lang->upgrade->fromVersions['9_0_1']      = '9.0.1';
$lang->upgrade->fromVersions['9_1']        = '9.1';
$lang->upgrade->fromVersions['9_1_1']      = '9.1.1';
$lang->upgrade->fromVersions['9_1_2']      = '9.1.2';
$lang->upgrade->fromVersions['9_2']        = '9.2';
$lang->upgrade->fromVersions['9_2_1']      = '9.2.1';
$lang->upgrade->fromVersions['9_3_beta']   = '9.3.beta';
$lang->upgrade->fromVersions['9_4']        = '9.4';
$lang->upgrade->fromVersions['9_5']        = '9.5';
$lang->upgrade->fromVersions['9_5_1']      = '9.5.1';
$lang->upgrade->fromVersions['9_6']        = '9.6';
$lang->upgrade->fromVersions['9_6_1']      = '9.6.1';
$lang->upgrade->fromVersions['9_6_2']      = '9.6.2';
$lang->upgrade->fromVersions['9_6_3']      = '9.6.3';
$lang->upgrade->fromVersions['9_7']        = '9.7';
$lang->upgrade->fromVersions['9_8']        = '9.8';
$lang->upgrade->fromVersions['9_8_1']      = '9.8.1';
$lang->upgrade->fromVersions['9_8_2']      = '9.8.2';
$lang->upgrade->fromVersions['9_8_3']      = '9.8.3';
$lang->upgrade->fromVersions['10_0_alpha'] = '10.0.alpha';
$lang->upgrade->fromVersions['10_0_beta']  = '10.0.beta';
$lang->upgrade->fromVersions['10_0']       = '10.0';
$lang->upgrade->fromVersions['10_1']       = '10.1';
$lang->upgrade->fromVersions['10_2']       = '10.2';
$lang->upgrade->fromVersions['10_3']       = '10.3';
$lang->upgrade->fromVersions['10_3_1']     = '10.3.1';
$lang->upgrade->fromVersions['10_4']       = '10.4';
$lang->upgrade->fromVersions['10_5']       = '10.5';
$lang->upgrade->fromVersions['10_5_1']     = '10.5.1';
$lang->upgrade->fromVersions['10_6']       = '10.6';
$lang->upgrade->fromVersions['11_0']       = '11.0';
$lang->upgrade->fromVersions['11_1']       = '11.1';
$lang->upgrade->fromVersions['11_2']       = '11.2';
$lang->upgrade->fromVersions['11_3']       = '11.3';
$lang->upgrade->fromVersions['11_4']       = '11.4';
$lang->upgrade->fromVersions['11_4_1']     = '11.4.1';
$lang->upgrade->fromVersions['11_5']       = '11.5';
$lang->upgrade->fromVersions['11_5_1']     = '11.5.1';
$lang->upgrade->fromVersions['11_5_2']     = '11.5.2';
$lang->upgrade->fromVersions['11_6']       = '11.6';
$lang->upgrade->fromVersions['11_6_1']     = '11.6.1';
$lang->upgrade->fromVersions['11_6_2']     = '11.6.2';
$lang->upgrade->fromVersions['11_6_3']     = '11.6.3';
$lang->upgrade->fromVersions['11_6_4']     = '11.6.4';
$lang->upgrade->fromVersions['11_6_5']     = '11.6.5';
$lang->upgrade->fromVersions['11_7']       = '11.7';
$lang->upgrade->fromVersions['12_0']       = '12.0';
$lang->upgrade->fromVersions['12_0_1']     = '12.0.1';
$lang->upgrade->fromVersions['12_1']       = '12.1';
$lang->upgrade->fromVersions['12_2']       = '12.2';
$lang->upgrade->fromVersions['12_3']       = '12.3';
$lang->upgrade->fromVersions['12_3_1']     = '12.3.1';
$lang->upgrade->fromVersions['12_3_2']     = '12.3.2';
$lang->upgrade->fromVersions['12_3_3']     = '12.3.3';
$lang->upgrade->fromVersions['12_4']       = '12.4';
$lang->upgrade->fromVersions['12_4_1']     = '12.4.1';

==> ZenTaoALM.12.5.3.int.zip: zentaoalm/module/upgrade/lang/version.php <==
<?php
$lang->upgrade->fromVersions['0_3beta']    = '0.3 BETA';
$lang->upgrade->fromVersions['0_4beta']    = '0.4 BETA';
$lang->upgrade->fromVersions['0_5beta']    = '0.5 BETA';
$lang->upgrade->fromVersions['0_6beta']    = '0.6 BETA';
$lang->upgrade->fromVersions['1_0beta']    = '1.0 BETA';
$lang->upgrade->fromVersions['1_0rc1']     = '1.0 RC1';
$lang->upgrade->fromVersions['1_0rc2']     = '1.0 RC2';
$lang->upgrade->fromVersions['1_0']        = '1.0 STABLE';
$lang->upgrade->fromVersions['1_0_1']      = '1.0.1';
$lang->upgrade->fromVersions['1_1']        = '1.1';
$lang->upgrade->fromVersions['1_2']        = '1.2';
$lang->upgrade->fromVersions['1_3']        = '1.3';
$lang->upgrade->fromVersions['1_4']        = '1.4';
$lang->upgrade->fromVersions['1_5']        = '1.5';
$lang->upgrade->fromVersions['2_0']        = '2.0';
$lang->upgrade->fromVersions['2_1']        = '2.1';
$lang->upgrade->fromVersions['2_2']        = '2.2';
$lang->upgrade->fromVersions['2_3']        = '2.3';
$lang->upgrade->fromVersions['2_4']        = '2.4';
$lang->upgrade->fromVersions['3_0_beta1']  = '3.0 BETA1';
$lang->upgrade->fromVersions['3_0_beta2']  = '3.0 BETA2';
$lang->upgrade->fromVersions['3_0']        = '3.0 STABLE';
$lang->upgrade->fromVersions['3_1']        = '3.1';
$lang->upgrade->fromVersions['3_2']        = '3.2';
$lang->upgrade->fromVersions['3_2_1']      = '3.2.1';
$lang->upgrade->fromVersions['3_3']        = '3.3';
$lang->upgrade->fromVersions['4_0_beta1']  = '4.0 BETA1';
$lang->upgrade->fromVersions['4_0_beta2']  = '4.0 BETA2';
$lang->upgrade->fromVersions['4_0']        = '4.0';
$lang->upgrade->fromVersions['4_0_1']      = '4.0.1';
$lang->upgrade->fromVersions['4_1']        = '4.1';
$lang->upgrade->fromVersions['4_2_beta']   = '4.2.beta';
$lang->upgrade->fromVersions['4_3_beta']   = '4.3.beta';
$lang->upgrade->fromVersions['5_0_beta1']  = '5.0.beta1';
$lang->upgrade->fromVersions['5_0_beta2']  = '5.0.beta2';
$lang->upgrade->fromVersions['5_0']        = '5.0';
$lang->upgrade->fromVersions['5_1']        = '5.1';
$lang->upgrade->fromVersions['5_2']        = '5.2';
$lang->upgrade->fromVersions['5_2_1']      = '5.2.1';
$lang->upgrade->fromVersions['5_3']        = '5.3';
$lang->upgrade->fromVersions['6_0_beta1']  = '6.0.beta1';
$lang->upgrade->fromVersions['6_0']        = '6.0';
$lang->upgrade->fromVersions['6_1']        = '6.1';
$lang->upgrade->fromVersions['6_2']        = '6.2';
$lang->upgrade->fromVersions['6_3']        = '6.3';
$lang->upgrade->fromVersions['6_4']        = '6.4';
$lang->upgrade->fromVersions['7_0']        = '7.0';
$lang->upgrade->fromVersions['7_1']        = '7.1';
$lang->upgrade->fromVersions['7_2']        = '7.2';
$lang->upgrade->fromVersions['7_2_4']      = '7.2.4';
$lang->upgrade->fromVersions['7_2_5']      = '7.2.5';
$lang->upgrade->fromVersions['7_3']        = '7.3';
$lang->upgrade->fromVersions['7_4_beta']   = '7.4.beta';
$lang->upgrade->fromVersions['8_0']        = '8.0';
$lang->upgrade->fromVersions['8_0_1']      = '8.0.1';
$lang->upgrade->fromVersions['8_1']        = '8.1';
$lang->upgrade->fromVersions['8_1_3']      = '8.1.3';
$lang->upgrade->fromVersions['8_2_beta']   = '8.2.beta';
$lang->upgrade->fromVersions['8_2']        = '8.2';
$lang->upgrade->fromVersions['8_2_1']      = '8.2.1';
$lang->upgrade->fromVersions['8_2_2']      = '8.2.2';
$lang->upgrade->fromVersions['8_2_3']      = '8.2.3';
$lang->upgrade->fromVersions['8_2_4']      = '8.2.4';
$lang->upgrade->fromVersions['8_2_5']      = '8.2.5';
$lang->upgrade->fromVersions['8_2_6']      = '8.2.6';
$lang->upgrade->fromVersions['8_3']        = '8.3';
$lang->upgrade->fromVersions['8_3_1']      = '8.3.1';
$lang->upgrade->fromVersions['8_4']        = '8.4';
$lang->upgrade->fromVersions['8_4_1']      = '8.4.1';
$lang->upgrade->fromVersions['9_0_beta']   = '9.0.beta';
$lang->upgrade->fromVersions['9_0']        = '9.0';
$lang->upgrade->fromVersions['9_0_1']      = '9.0.1';
$lang->upgrade->fromVersions['9_1']        = '9.1';
$lang->upgrade->fromVersions['9_1_1']      = '9.1.1';
$lang->upgrade->fromVersions['9_1_2']      = '9.1.2';
$lang->upgrade->fromVersions['9_2']        = '9.2';
$lang->upgrade->fromVersions['9_2_1']      = '9.2.1';
$lang->upgrade->fromVersions['9_3_beta']   = '9.3.beta';
$lang->upgrade->fromVersions['9_4']        = '9.4';
$lang->upgrade->fromVersions['9_5']        = '9.5';
$lang->upgrade->fromVersions['9_5_1']      = '9.5.1';
$lang->upgrade->fromVersions['9_6']        = '9.6';
$lang->upgrade->fromVersions['9_6_1']      = '9.6.1';
$lang->upgrade->fromVersions['9_6_2']      = '9.6.2';
$lang->upgrade->fromVersions['9_6_3']      = '9.6.3';
$lang->upgrade->fromVersions['9_7']        = '9.7';
$lang->upgrade->fromVersions['9_8']        = '9.8';
$lang->upgrade->fromVersions['9_8_1']      = '9.8.1';
$lang->upgrade->fromVersions['9_8_2']      = '9.8.2';
$lang->upgrade->fromVersions['9_8_3']      = '9.8.3';
$lang->upgrade->fromVersions['10_0_alpha'] = '10.0.alpha';
$lang->upgrade->fromVersions['10_0_beta']  = '10.0.beta';
$lang->upgrade->fromVersions['10_0']       = '10.0';
$lang->upgrade->fromVersions['10_1']       = '10.1';
$lang->upgrade->fromVersions['10_2']       = '10.2';
$lang->upgrade->fromVersions['10_3']       = '10.3';
$lang->upgrade->fromVersions['10_3_1']     = '10.3.1';
$lang->upgrade->fromVersions['10_4']       = '10.4';
$lang->upgrade->fromVersions['10_5']       = '10.5';
$lang->upgrade->fromVersions['10_5_1']     = '10.5.1';
$lang->upgrade->fromVersions['10_6']       = '10.6';
$lang->upgrade->fromVersions['11_0']       = '11.0';
$lang->upgrade->fromVersions['11_1']       = '11.1';
$lang->upgrade->fromVersions['11_2']       = '11.2';
$lang->upgrade->fromVersions['11_3']       = '11.3';
$lang->upgrade->fromVersions['11_4']       = '11.4';
$lang->upgrade->fromVersions['11_4_1']     = '11.4.1';
$lang->upgrade->fromVersions['11_5']       = '11.5';
$lang->upgrade->fromVersions['11_5_1']     = '11.5.1';
$lang->upgrade->fromVersions['11_5_2']     = '11.5.2';
$lang->upgrade->fromVersions['11_6']       = '11.6';
$lang->upgrade->fromVersions['11_6_1']     = '11.6.1';
$lang->upgrade->fromVersions['11_6_2']     = '11.6.2';
$lang->upgrade->fromVersions['11_6_3']     = '11.6.3';
$lang->upgrade->fromVersions['11_6_4']     = '11.6.4';
$lang->upgrade->fromVersions['11_6_5']     = '11.6.5';
$lang->upgrade->fromVersions['11_7']       = '11.7';
$lang->upgrade->fromVersions['12_0']       = '12.0';
$lang->upgrade->fromVersions['12_0_1']     = '12.0.1';
$lang->upgrade->fromVersions['12_1']       = '12.1';
$lang->upgrade->fromVersions['12_2']       = '12.2';
$lang->upgrade->fromVersions['12_3']       = '12.3';
$lang->upgrade->fromVersions['12_3_1']     = '12.3.1';
$lang->upgrade->fromVersions['12_3_2']     = '12.3.2';
$lang->upgrade->fromVersions['12_3_3']     = '12.3.3';
$lang->upgrade->fromVersions['12_4']       = '12.4';
$lang->upgrade->fromVersions['12_4_1']     = '12.4.1';
$lang->upgrade->fromVersions['12_4_2']     = '12.4.2';
$lang->upgrade->fromVersions['12_4_3']     = '12.4.3';
$lang->upgrade->fromVersions['12_4_4']     = '12.4.4';
$lang->upgrade->fromVersions['12_5']       = '12.5';
$lang->upgrade->fromVersions['12_5_1']     = '12.5.1';
$lang->upgrade->fromVersions['12_5_2']     = '12.5.2';
